@@ -1,4 +1,5 @@
 # File: ytget_gui/dialogs/preferences.py
+
 from __future__ import annotations
 
 import datetime
@@ -11,7 +12,7 @@ from PySide6.QtCore import QDate
 from ytget_gui.styles import AppStyles
 from ytget_gui.settings import AppSettings
 from ytget_gui.dialogs.advanced import UISwitch
-
+from ytget_gui.workers import cookies as CookieManager
 
 _SPONSORBLOCK_CATEGORIES = {
     "Sponsor": "sponsor",
@@ -415,11 +416,39 @@ class PreferencesDialog(QtWidgets.QDialog):
 
         self.cookies_browser_combo = QtWidgets.QComboBox()
         self.cookies_browser_combo.setObjectName("combo")
-        self.cookies_browser_combo.addItems(["", "chrome", "firefox", "edge", "opera", "vivaldi"])
+        self.cookies_browser_combo.addItems(["", "chrome", "chromium", "edge", "firefox", "opera", "brave", "vivaldi", "safari", "whale"])
         self.cookies_browser_combo.setAccessibleName("Import cookies from browser")
         self._base_tips[self.cookies_browser_combo] = "Import cookies directly from a supported browser profile"
         pf.addWidget(self._form_row("Import from browser", self.cookies_browser_combo))
 
+        # Manual import row: browser selector + Import Now button
+        self.import_cookies_combo = QtWidgets.QComboBox()
+        self.import_cookies_combo.setObjectName("combo")
+        self.import_cookies_combo.addItems(["", "chrome", "chromium", "edge", "firefox", "opera", "brave", "vivaldi", "safari", "whale"])
+        self.import_cookies_combo.setAccessibleName("Browser for import")
+
+        self.import_cookies_btn = QtWidgets.QPushButton("Import YouTube cookies now")
+        self.import_cookies_btn.setMinimumHeight(36)
+        self.import_cookies_btn.clicked.connect(self._on_import_cookies)
+
+        imp_row = QtWidgets.QWidget()
+        imp_h = QtWidgets.QHBoxLayout(imp_row)
+        imp_h.setContentsMargins(0, 0, 0, 0)
+        imp_h.setSpacing(8)
+        imp_h.addWidget(self.import_cookies_combo, 1)
+        imp_h.addWidget(self.import_cookies_btn, 0)
+
+        pf.addWidget(self._form_row("Import cookies", imp_row, "Export fresh cookies from a local browser profile"))
+
+        self.cookies_auto_refresh = QtWidgets.QCheckBox("Refresh cookies before each download")
+        self.cookies_auto_refresh.setObjectName("check")
+        self.cookies_auto_refresh.setToolTip("Attempt to export fresh cookies from the selected browser before each download")
+        pf.addWidget(self._form_row("", self.cookies_auto_refresh))
+
+        self.cookies_last_label = QtWidgets.QLabel("")
+        self.cookies_last_label.setObjectName("formDescription")
+        pf.addWidget(self.cookies_last_label)
+
         proxy_card = self._card(
             proxy_form,
             title="Network access",
@@ -632,25 +661,25 @@ class PreferencesDialog(QtWidgets.QDialog):
         self._tweak_toggle(self.audio_normalize)
         self.audio_normalize.setAccessibleName("Normalize audio volume")
         self.audio_normalize.setEnabled(True)
-        fl.addWidget(self._form_row("Audio normalize", self.audio_normalize, "Adjust volume to a consistent level"))
+        fl.addWidget(self._form_row("Audio Normalize", self.audio_normalize, "Adjust Volume to A Consistent Level"))
 
         self.add_metadata = UISwitch("")
         self._tweak_toggle(self.add_metadata)
         self.add_metadata.setAccessibleName("Add metadata to files")
         self.add_metadata.setEnabled(True)
-        fl.addWidget(self._form_row("Metadata", self.add_metadata, "Write tags (title, artist, album) into files"))
+        fl.addWidget(self._form_row("Metadata", self.add_metadata, "Write Tags (Title, Artist, Album) Into Files"))
 
         self.crop_covers = UISwitch("")
         self._tweak_toggle(self.crop_covers)
         self.crop_covers.setAccessibleName("Crop audio covers to square")
         self.crop_covers.setEnabled(True)
-        fl.addWidget(self._form_row("Covers", self.crop_covers, "Crop artwork to a 1:1 aspect ratio"))
+        fl.addWidget(self._form_row("Audio Covers", self.crop_covers, "Crop Artwork to A 1:1 Aspect Ratio"))
         
         self.video_format_combo = QtWidgets.QComboBox()
         self.video_format_combo.setObjectName("combo")
         self.video_format_combo.addItems([".mkv", ".mp4", ".webm"])
         self.video_format_combo.setAccessibleName("Preferred video format")
-        fl.addWidget(self._form_row("Video format", self.video_format_combo, "Choose output container"))
+        fl.addWidget(self._form_row("Video Format", self.video_format_combo, "Choose Output Container"))
 
         self.custom_ffmpeg = self._line_edit(
             placeholder="-c:v libx265 -crf 23",
@@ -659,6 +688,41 @@ class PreferencesDialog(QtWidgets.QDialog):
         self.custom_ffmpeg.setAccessibleName("Custom FFmpeg arguments")
         fl.addWidget(self._form_row("Custom FFmpeg args", self.custom_ffmpeg))
 
+        # ─────────── Thumbnail toggles ───────────
+        self.write_thumbnail = UISwitch("")
+        self._tweak_toggle(self.write_thumbnail)
+        self.write_thumbnail.setAccessibleName("Download thumbnails")
+        fl.addWidget(
+            self._form_row(
+                "Thumbnail",
+                self.write_thumbnail,
+                "Save the Original Thumbnail File Alongside the Audio/Video",
+            )
+        )
+
+        self.convert_thumbnails = UISwitch("")
+        self._tweak_toggle(self.convert_thumbnails)
+        self.convert_thumbnails.setAccessibleName("Convert thumbnails")
+        fl.addWidget(
+            self._form_row(
+                "Convert Thumbnail",
+                self.convert_thumbnails,
+                "Convert Downloaded Thumbnail to PNG",
+            )
+        )
+
+        self.embed_thumbnail = UISwitch("")
+        self._tweak_toggle(self.embed_thumbnail)
+        self.embed_thumbnail.setAccessibleName("Embed thumbnail")
+        fl.addWidget(
+            self._form_row(
+                "Embed Thumbnail",
+                self.embed_thumbnail,
+                "Embed the Thumbnail Into the Video’s Metadata",
+            )
+        )
+        # ───────────────────────────────────────────
+
         card = self._card(form, title="Post-processing", subtitle="Fine-tune audio, metadata, and FFmpeg options.")
         pv.addWidget(card)
         return page
@@ -724,7 +788,7 @@ class PreferencesDialog(QtWidgets.QDialog):
         return page
 
     # ---------- Styling ----------
-    def _apply_styles(self) -> None:
+    def _apply_styles(self) -> None:               
         base = ""
         try:
             base = getattr(AppStyles, "DIALOG", "") or ""
@@ -948,6 +1012,41 @@ class PreferencesDialog(QtWidgets.QDialog):
         if path:
             self.cookies_path_input.setText(path)
 
+    def _on_import_cookies(self) -> None:
+        browser = self.import_cookies_combo.currentText().strip() or self.cookies_browser_combo.currentText().strip()
+        if not browser:
+            QtWidgets.QMessageBox.information(self, "Select browser", "Please choose a browser profile to import from.")
+            return
+
+        out = Path(self.settings.BASE_DIR) / "cookies.txt"
+        ok, msg = CookieManager.export_for_browser(browser, out)   
+        if ok:
+            self.cookies_path_input.setText(str(out))
+
+            # Use a timestamp label for last import
+            from datetime import datetime
+            ts = datetime.utcnow().strftime("%Y-%m-%d %H:%M:%S UTC")
+            label_text = f"Last imported: {out.name} ({ts})"
+            self.cookies_last_label.setText(label_text)
+
+            # Update running settings and persist immediately
+            try:
+                # Keep stored metadata in settings in a stable form
+                if hasattr(self.settings, "COOKIES_LAST_IMPORTED"):
+                    # store the timestamped label (human readable)
+                    self.settings.COOKIES_LAST_IMPORTED = label_text.replace("Last imported: ", "")
+                if hasattr(self.settings, "COOKIES_PATH"):
+                    # keep settings.COOKIES_PATH in sync with exported file
+                    self.settings.COOKIES_PATH = out
+                if hasattr(self.settings, "save_config"):
+                    self.settings.save_config()
+            except Exception:
+                pass
+
+            QtWidgets.QMessageBox.information(self, "Imported cookies", msg)                       
+        else:
+            QtWidgets.QMessageBox.warning(self, "Import failed", msg)
+
     def _browse_archive(self) -> None:
         path, _ = QtWidgets.QFileDialog.getSaveFileName(
             self,
@@ -1107,6 +1206,9 @@ class PreferencesDialog(QtWidgets.QDialog):
             self.proxy_input,
             self.cookies_path_input,
             self.cookies_browser_combo,
+            self.import_cookies_combo,
+            self.cookies_auto_refresh,
+            self.cookies_last_label,
             self.limit_rate_input,
             self.retries_spin,
             # SponsorBlock
@@ -1131,6 +1233,9 @@ class PreferencesDialog(QtWidgets.QDialog):
             self.crop_covers,
             self.custom_ffmpeg,
             self.video_format_combo,
+            self.write_thumbnail,
+            self.convert_thumbnails,
+            self.embed_thumbnail,
             # Output
             self.organize_uploader,
             self.date_after,
@@ -1277,6 +1382,9 @@ class PreferencesDialog(QtWidgets.QDialog):
         self.proxy_input.setText(getattr(self.settings, "PROXY_URL", "") or "")
         self.cookies_path_input.setText(str(getattr(self.settings, "COOKIES_PATH", "") or ""))
         self.cookies_browser_combo.setCurrentText(getattr(self.settings, "COOKIES_FROM_BROWSER", "") or "")
+        self.cookies_auto_refresh.setChecked(bool(getattr(self.settings, "COOKIES_AUTO_REFRESH", False)))
+        last = getattr(self.settings, "COOKIES_LAST_IMPORTED", "")
+        self.cookies_last_label.setText(f"Last imported: {last}" if last else "")        
         self.retries_spin.setValue(int(getattr(self.settings, "RETRIES", 3)))
         self.limit_rate_input.setText(getattr(self.settings, "LIMIT_RATE", "") or "")
 
@@ -1316,6 +1424,13 @@ class PreferencesDialog(QtWidgets.QDialog):
         vf = getattr(self.settings, "VIDEO_FORMAT", ".mkv") or ".mkv"
         if vf not in (".mkv", ".mp4", ".webm"):
             vf = ".mkv"
+        
+        # ─────────── Thumbnail state ───────────
+        self.write_thumbnail.setChecked(bool(getattr(self.settings, "WRITE_THUMBNAIL", False)))
+        self.convert_thumbnails.setChecked(bool(getattr(self.settings, "CONVERT_THUMBNAILS", True)))
+        self.embed_thumbnail.setChecked(bool(getattr(self.settings, "EMBED_THUMBNAIL", True)))
+        # ─────────────────────────────────────────
+       
         self.video_format_combo.setCurrentText(vf)
 
         # Output
@@ -1395,6 +1510,8 @@ class PreferencesDialog(QtWidgets.QDialog):
             "PROXY_URL": self.proxy_input.text().strip(),
             "COOKIES_PATH": Path(self.cookies_path_input.text().strip()) if self.cookies_path_input.text().strip() else Path(""),
             "COOKIES_FROM_BROWSER": self.cookies_browser_combo.currentText().strip(),
+            "COOKIES_AUTO_REFRESH": self.cookies_auto_refresh.isChecked(),
+            "COOKIES_LAST_IMPORTED": self.cookies_last_label.text().replace("Last imported: ", "") if self.cookies_last_label.text() else "",
             "SPONSORBLOCK_CATEGORIES": sb,
             "CHAPTERS_MODE": ch_mode,
             "WRITE_SUBS": self.subtitles_enabled.isChecked(),
@@ -1409,6 +1526,11 @@ class PreferencesDialog(QtWidgets.QDialog):
             "ADD_METADATA": self.add_metadata.isChecked(),
             "CROP_AUDIO_COVERS": self.crop_covers.isChecked(),
             "CUSTOM_FFMPEG_ARGS": self.custom_ffmpeg.text().strip(),
+            # ─────────── Thumbnail flags ───────────
+            "WRITE_THUMBNAIL":    self.write_thumbnail.isChecked(),
+            "CONVERT_THUMBNAILS": self.convert_thumbnails.isChecked(),
+            "EMBED_THUMBNAIL":    self.embed_thumbnail.isChecked(),
+            # ─────────────────────────────────────────
             "VIDEO_FORMAT": self.video_format_combo.currentText(),
             "ORGANIZE_BY_UPLOADER": self.organize_uploader.isChecked(),
             "DATEAFTER": self.date_after.text().strip(),
@@ -1430,6 +1552,14 @@ class PreferencesDialog(QtWidgets.QDialog):
                 except Exception:
                     # هgnore non-writable attributes
                     pass
+        try:
+            # Persist settings so choices like COOKIES_FROM_BROWSER and COOKIES_AUTO_REFRESH
+            # are saved immediately to disk (config.json)
+            if hasattr(self.settings, "save_config"):
+                self.settings.save_config()
+        except Exception:
+            # Swallow persistence errors to avoid blocking the UI
+            pass
 
     def validate_and_accept(self) -> None:
         self._validate_all()
@@ -1556,4 +1686,4 @@ class PreferencesDialog(QtWidgets.QDialog):
         for lbl in self._label_refs:
             max_w = max(max_w, fm.horizontalAdvance(lbl.text()) + 8)
         for lbl in self._label_refs:
-            lbl.setMinimumWidth(max_w)
\ No newline at end of file
+            lbl.setMinimumWidth(max_w)
